pub struct TestMetricsReader { /* private fields */ }Trait Implementations
Sourceimpl Clone for TestMetricsReader
impl Clone for TestMetricsReader
Sourcefn clone(&self) -> TestMetricsReader
fn clone(&self) -> TestMetricsReader
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TestMetricsReader
impl Debug for TestMetricsReader
Sourceimpl Default for TestMetricsReader
impl Default for TestMetricsReader
Sourceimpl MetricReader for TestMetricsReader
impl MetricReader for TestMetricsReader
Sourcefn register_pipeline(&self, pipeline: Weak<Pipeline>)
fn register_pipeline(&self, pipeline: Weak<Pipeline>)
Registers a MetricReader with a [Pipeline]. Read more
Sourcefn collect(&self, rm: &mut ResourceMetrics) -> OTelSdkResult
fn collect(&self, rm: &mut ResourceMetrics) -> OTelSdkResult
Gathers and returns all metric data related to the MetricReader from the
SDK and stores it in the provided ResourceMetrics reference. Read more
Sourcefn force_flush(&self) -> OTelSdkResult
fn force_flush(&self) -> OTelSdkResult
Flushes all metric measurements held in an export pipeline. Read more
Sourcefn shutdown(&self) -> OTelSdkResult
fn shutdown(&self) -> OTelSdkResult
shutdown with default timeout
Sourcefn shutdown_with_timeout(&self, timeout: Duration) -> OTelSdkResult
fn shutdown_with_timeout(&self, timeout: Duration) -> OTelSdkResult
Flushes all metric measurements held in an export pipeline and releases any
held computational resources. Read more
Sourcefn temporality(&self, _kind: InstrumentKind) -> Temporality
fn temporality(&self, _kind: InstrumentKind) -> Temporality
The output temporality, a function of instrument kind.
This SHOULD be obtained from the exporter. Read more